#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-hlint-plugin-2.3.0.0-Fyzxa0BcNHY26cicDjgUqR
key:                  hls-hlint-plugin-2.3.0.0-Fyzxa0BcNHY26cicDjgUqR
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  85761d08f1afc86105a37183946e864a
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.3.0.0-Fyzxa0BcNHY26cicDjgUqR
depends:
    Diff-0.5-CVmokWbg8IGGOMUXqgoBQG aeson-2.2.2.0-vFmFQLvGml64UTioNorrR
    apply-refact-0.14.0.0-2yH0ZMIGhJRCaNliuC2a0S base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-2Ws4ESP8WrPAiAEeWb6jqc
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-AtFBZnSPIDt2Yj9q7Ev4S
    ghc-lib-parser-ex-9.6.0.2-dHHAw4NYaM1bYlM9Fbrtd
    ghcide-2.3.0.0-CoWdGXpgo9v7X1K9P59KNN
    hashable-1.4.7.0-3I1JJMFn7WVBoCbELVuec1
    hlint-3.6.1-JWeblSF1SDN3QqOFeYAfx2
    hls-plugin-api-2.3.0.0-InTWXP6EhU52WB6ocwpWzm
    lens-5.3.4-IWoRR3qkHJ5zZoQTNAEtG lsp-2.2.0.0-F8G4UrPWcFQA5Bitqmz4F6
    mtl-2.3.1 refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    regex-tdfa-1.3.2.5-5OiPEKUbH5lBmb0AzqfBQo stm-2.5.1.0
    temporary-1.3-1srnU80DzzY9Jc5aotkmdm text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-A7v2mkdOMedFLrtoUSJIsH

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

